@@ -24,6 +24,7 @@ def run_snakemake(
     verbose=False,
     snakefile_name="Snakefile",
     outdir=None,
+    config_params=[],
     extra_args=[],
 ):
     # find the Snakefile relative to package path
@@ -32,41 +33,49 @@ def run_snakemake(
     # basic command
     cmd = ["snakemake", "-s", snakefile]
 
-    # add --use-conda
-    if not no_use_conda:
-        cmd += ["--use-conda"]
-
-    # add --outdir
-    if outdir:
-        cmd += ["--config", f"outdir={outdir}"]
-
     # snakemake sometimes seems to want a default -j; set it to 1 for now.
     # can overridden later on command line.
     cmd += ["-j", "1"]
 
+    # add --use-conda
+    if not no_use_conda:
+        cmd += ["--use-conda"]
+
     # add rest of snakemake arguments
     cmd += list(extra_args)
 
+    # add config params, and --outdir
+    if outdir:
+        config_params = list(config_params)
+        config_params.append(f"outdir={outdir}")
+
+    if config_params:
+        cmd += ["--config", *config_params]
+
     # add configfile - try looking for it a few different ways.
-    configfiles = []
-    if os.path.isfile(configfile):
-        configfiles = [configfile]
-    elif os.path.isfile(get_package_configfile(configfile)):
-        configfiles = [get_package_configfile(configfile)]
-    else:
-        for suffix in ".yaml", ".conf":
-            tryfile = configfile + suffix
-            if os.path.isfile(tryfile):
-                configfiles = [tryfile]
-                break
+    configfiles = [
+        get_package_configfile("defaults.conf"),
+        get_package_configfile("system.conf"),
+    ]
+    if configfile:
+        if os.path.isfile(configfile):
+            configfiles.append(configfile)
+        elif os.path.isfile(get_package_configfile(configfile)):
+            configfiles.append(get_package_configfile(configfile))
+        else:
+            for suffix in ".yaml", ".conf":
+                tryfile = configfile + suffix
+                if os.path.isfile(tryfile):
+                    configfiles.append(tryfile)
+                    break
 
-            tryfile = get_package_configfile(tryfile)
-            if os.path.isfile(tryfile):
-                configfiles = [tryfile]
-                break
+                tryfile = get_package_configfile(tryfile)
+                if os.path.isfile(tryfile):
+                    configfiles.append(tryfile)
+                    break
 
-    if not configfiles:
-        raise ValueError(f"cannot find config file '{configfile}'")
+        if len(configfiles) == 2:
+            raise ValueError(f"cannot find config file '{configfile}'")
 
     cmd += ["--configfile"] + configfiles
 
@@ -124,9 +133,9 @@ def run(configfile, snakemake_args, no_use_conda, verbose, outdir):
 def process(sample, snakemake_args, no_use_conda, verbose, outdir):
     "execute genome-grist workflow (using snakemake underneath)"
     snakemake_args = list(snakemake_args)
-    snakemake_args += ['--config', f'sample={sample}']
+    snakemake_args += ["--config", f"sample={sample}"]
     run_snakemake(
-        'conf.yml',
+        None,
         snakefile_name="Snakefile",
         no_use_conda=no_use_conda,
         verbose=verbose,
